bayespy.inference.vmp.transformations.RotateSwitchingMarkovChain
================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. autoclass:: RotateSwitchingMarkovChain

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~RotateSwitchingMarkovChain.__init__
      ~RotateSwitchingMarkovChain.bound
      ~RotateSwitchingMarkovChain.get_bound_terms
      ~RotateSwitchingMarkovChain.nodes
      ~RotateSwitchingMarkovChain.rotate
      ~RotateSwitchingMarkovChain.setup
   
   

   
   
   